@@ -5,6 +5,7 @@ import argparse
 import asyncio
 import os
 import sys
+from ast import arg
 from datetime import datetime
 
 import pytz
@@ -37,7 +38,7 @@ def date_type(value: str):
         raise argparse.ArgumentTypeError(f"Invalid date {value}, expected YYYY-MM-DD.")
 
 
-def build_dataset_from_tog_command(parser: argparse.ArgumentParser):
+def create_job_args(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
     parser.add_argument(
         "-j",
         "--job-id",
@@ -45,6 +46,58 @@ def build_dataset_from_tog_command(parser: argparse.ArgumentParser):
         required=True,
         help="Id of the tog dataset that we want to download.",
     )
+    parser.add_argument(
+        "--start-date",
+        type=date_type,
+        help="Filter items added to the dataset after this date. (inclusive)",
+    )
+    parser.add_argument(
+        "--end-date",
+        type=date_type,
+        help="Filter items added to the dataset before this date. (exclusive)",
+    )
+    parser.add_argument(
+        "--db", type=str, help="Database name.", default=os.environ.get(const.TOGDB_DB)
+    )
+    parser.add_argument(
+        "--host",
+        type=str,
+        help="Database host.",
+        default=os.environ.get(const.TOGDB_HOST),
+    )
+    parser.add_argument(
+        "--port",
+        type=int,
+        help="Database port.",
+        default=os.environ.get(const.TOGDB_PORT),
+    )
+    parser.add_argument(
+        "--user",
+        type=str,
+        help="Database user.",
+        default=os.environ.get(const.TOGDB_USER),
+    )
+    parser.add_argument(
+        "--password",
+        type=str,
+        help="Database password.",
+        default=os.environ.get(const.TOGDB_PASSWORD),
+    )
+    return parser
+
+
+def add_job_args(fn):
+    def wrapper(*args, **kwargs):
+        parser = fn(*args, **kwargs)
+        return create_job_args(parser)
+
+    return wrapper
+
+
+@add_job_args
+def build_dataset_from_tog_command(
+    parser: argparse.ArgumentParser,
+) -> argparse.ArgumentParser:
     parser.add_argument(
         "-o",
         "--output-format",
@@ -79,19 +132,12 @@ def build_dataset_from_tog_command(parser: argparse.ArgumentParser):
         help="Task type for deserialization.",
         choices=const.TASK_TYPES,
     )
-    parser.add_argument(
-        "--start-date",
-        type=date_type,
-        help="Filter items added to the dataset after this date. (inclusive)",
-    )
-    parser.add_argument(
-        "--end-date",
-        type=date_type,
-        help="Filter items added to the dataset before this date. (exclusive)",
-    )
+    return parser
 
 
-def build_dataset_from_dvc_command(parser: argparse.ArgumentParser) -> None:
+def build_dataset_from_dvc_command(
+    parser: argparse.ArgumentParser,
+) -> argparse.ArgumentParser:
     parser.add_argument(
         "--repo", type=str, required=True, help="DVC enabled git repository."
     )
@@ -102,9 +148,10 @@ def build_dataset_from_dvc_command(parser: argparse.ArgumentParser) -> None:
         help="Remote. Required only if the repo "
         "hasn't set a default remote. This is usually a bucket name.",
     )
+    return parser
 
 
-def build_download_command(parser: argparse.ArgumentParser) -> None:
+def build_download_command(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
     data_source_parsers = parser.add_subparsers(dest="data_source")
     build_dataset_from_tog_command(
         data_source_parsers.add_parser(
@@ -120,16 +167,12 @@ def build_download_command(parser: argparse.ArgumentParser) -> None:
             formatter_class=argparse.ArgumentDefaultsHelpFormatter,
         )
     )
+    return parser
 
 
-def upload_dataset_to_tog_command(parser: argparse.ArgumentParser) -> None:
-    parser.add_argument(
-        "-j",
-        "--job-id",
-        type=is_numeric,
-        required=True,
-        help="Dataset id where the data should be uploaded.",
-    )
+def upload_dataset_to_tog_command(
+    parser: argparse.ArgumentParser,
+) -> argparse.ArgumentParser:
     parser.add_argument(
         "--url",
         type=str,
@@ -148,6 +191,7 @@ def upload_dataset_to_tog_command(parser: argparse.ArgumentParser) -> None:
         type=str,
         help="The raw data to be uploaded.",
     )
+    return parser
 
 
 def build_upload_command(parser: argparse.ArgumentParser) -> None:
@@ -161,25 +205,6 @@ def build_upload_command(parser: argparse.ArgumentParser) -> None:
     )
 
 
-def build_describe_command(parser: argparse.ArgumentParser):
-    parser.add_argument(
-        "--job-id",
-        type=is_numeric,
-        required=True,
-        help="Id of the tog dataset that we want to describe.",
-    )
-
-
-def build_stats_command(parser: argparse.ArgumentParser):
-    parser.add_argument(
-        "--job-id",
-        type=is_numeric,
-        required=True,
-        help="Check the state of the dataset i.e tagged, "
-        "untagged and pending data points for a given job-id.",
-    )
-
-
 def build_cli():
     parser = argparse.ArgumentParser(
         description=f"skit-labels {__version__}. Command line interface for interacting with labelled datasets.",
@@ -201,12 +226,12 @@ def build_cli():
             help="Upload a dataset.",
         )
     )
-    build_describe_command(
+    create_job_args(
         command_parsers.add_parser(
             const.DESCRIBE, help="Describe a dataset for a given tog dataset id."
         )
     )
-    build_stats_command(
+    create_job_args(
         command_parsers.add_parser(
             const.STATS, help="Get tagged/untagged points for a given tog dataset id."
         )
@@ -214,6 +239,18 @@ def build_cli():
     return parser
 
 
+def upload_dataset(input_file, url, token, job_id):
+    errors, df_size = asyncio.run(
+        commands.upload_dataset_to_db(
+            input_file,
+            url,
+            token,
+            job_id,
+        )
+    )
+    return errors, df_size
+
+
 def cmd_to_str(args: argparse.Namespace) -> str:
     utils.configure_logger(args.verbosity)
     if args.command == const.DOWNLOAD and args.data_source == const.SOURCE__DB:
@@ -226,6 +263,11 @@ def cmd_to_str(args: argparse.Namespace) -> str:
             output_format=args.output_format,
             start_date=args.start_date,
             end_date=args.end_date,
+            db=args.db,
+            host=args.host,
+            port=args.port,
+            user=args.user,
+            password=args.password,
         )
     elif args.command == const.DOWNLOAD and args.data_source == const.SOURCE__DVC:
         return commands.download_dataset_from_dvc(args.repo, args.path, args.remote)
@@ -245,22 +287,33 @@ def cmd_to_str(args: argparse.Namespace) -> str:
                     "Expected to receive --input=<file> or its valued piped in."
                 )
 
-        errors, df_size = asyncio.run(
-            commands.upload_dataset_to_db(
-                args.input,
-                args.url,
-                args.token,
-                job_id=args.job_id,
-            )
-        )
+        upload_dataset(args.input, args.url, args.token, args.job_id)
 
         if errors:
             error_summary = "\n".join(set(errors))
-            return f"Encountered {len(errors)} over {df_size}.\nSummary:\n{error_summary}."
+            return (
+                f"Encountered {len(errors)} over {df_size}.\nSummary:\n{error_summary}."
+            )
     elif args.command == const.DESCRIBE:
-        return commands.describe_dataset(args.job_id)
+        return commands.describe_dataset(
+            args.job_id,
+            start_date=args.start_date,
+            end_date=args.end_date,
+            db=args.db,
+            host=args.host,
+            port=args.port,
+            user=args.user,
+            password=args.password,
+        )
     elif args.command == const.STATS:
-        return commands.stat_dataset(args.job_id)
+        return commands.stat_dataset(
+            args.job_id,
+            db=args.db,
+            host=args.host,
+            port=args.port,
+            user=args.user,
+            password=args.password,
+        )
 
 
 def main():
@@ -270,6 +323,7 @@ def main():
     if args.command == const.DOWNLOAD and args.data_source == const.SOURCE__DB:
         # Since the first element is the file, message[1] is the dataset type.
         print(message[0])
+    elif args.command == const.STATS:
+        print(commands.print_job_stats(message))
     else:
         print(message)
-
