@@ -2,7 +2,7 @@ import asyncio
 import json
 import os
 import tempfile
-from typing import Iterable, List, Optional, Tuple
+from typing import Iterable, List, Optional, Tuple, Union
 
 import aiohttp
 import attr
@@ -43,8 +43,24 @@ def download_dataset(
     batch_size: int = 500,
     start_date: Optional[str] = None,
     end_date: Optional[str] = None,
+    db: Optional[str] = None,
+    user: Optional[str] = None,
+    password: Optional[str] = None,
+    host: Optional[str] = None,
+    port: Optional[Union[int, str]] = None,
 ) -> Tuple[SqliteDatabase, str, str]:
-    job = Job(int(job_id), task_type=task_type, tz=timezone)
+    job = Job(
+        int(job_id),
+        task_type=task_type,
+        tz=timezone,
+        start_date=start_date,
+        end_date=end_date,
+        db=db,
+        user=user,
+        password=password,
+        host=host,
+        port=port,
+    )
     describe_dataset(job_id)
     stat_dataset(job_id)
 
@@ -81,19 +97,62 @@ def sdb2df(sdb: SqliteDatabase, job_id: str) -> str:
     return output_file
 
 
-def describe_dataset(job_id: Optional[int] = None, job: Optional[Job] = None) -> str:
-    job_ = job or Job(job_id)
-    return f"Job {job_.id}: {job_.name} [language: {job_.lang}]\n{job_.description}"
+def describe_dataset(
+    job_id: Optional[int] = None,
+    job: Optional[Job] = None,
+    db: Optional[str] = None,
+    user: Optional[str] = None,
+    password: Optional[str] = None,
+    host: Optional[str] = None,
+    port: Optional[Union[int, str]] = None,
+) -> str:
+    return job or Job(
+        int(job_id),
+        db=db,
+        user=user,
+        password=password,
+        host=host,
+        port=port,
+    )
 
 
-def stat_dataset(job_id: Optional[int] = None, job: Optional[Job] = None) -> str:
-    job_ = job or Job(job_id)
+def stat_dataset(
+    job_id: Optional[int] = None,
+    job: Optional[Job] = None,
+    start_date: Optional[str] = None,
+    end_date: Optional[str] = None,
+    db: Optional[str] = None,
+    user: Optional[str] = None,
+    password: Optional[str] = None,
+    host: Optional[str] = None,
+    port: Optional[Union[int, str]] = None,
+) -> dict:
+    job_ = job or Job(
+        int(job_id),
+        start_date=start_date,
+        end_date=end_date,
+        db=db,
+        user=user,
+        password=password,
+        host=host,
+        port=port,
+    )
     n_total = job_.total(untagged=True)
     n_tagged = job_.total()
-    return f"Total items {n_total}. Tagged {n_tagged}. Untagged {n_total - n_tagged}."
+    return {
+        const.TOTAL: n_total,
+        const.TAGGED: n_tagged,
+        const.UNTAGGED: n_total - n_tagged,
+    }
 
 
-def download_dataset_from_dvc(repo: str, path: str, remote: Optional[str] = None) -> str:
+def print_job_stats(job_stats: dict) -> str:
+    return json.dumps(job_stats, indent=2)
+
+
+def download_dataset_from_dvc(
+    repo: str, path: str, remote: Optional[str] = None
+) -> str:
     file_name = os.path.split(path)[-1]
     _, output_file = tempfile.mkstemp(suffix=file_name)
     with dvc.api.open(path, repo=repo, remote=remote) as f:
@@ -111,6 +170,11 @@ def download_dataset_from_db(
     output_format: str = const.OUTPUT_FORMAT__CSV,
     start_date: Optional[str] = None,
     end_date: Optional[str] = None,
+    db: Optional[str] = None,
+    user: Optional[str] = None,
+    password: Optional[str] = None,
+    host: Optional[str] = None,
+    port: Optional[Union[int, str]] = None,
 ) -> Tuple[str, str]:
     sdb, sdb_path, dataset_type = download_dataset(
         job_id,
@@ -120,6 +184,11 @@ def download_dataset_from_db(
         batch_size,
         start_date=start_date,
         end_date=end_date,
+        db=db,
+        user=user,
+        password=password,
+        host=host,
+        port=port,
     )
     if output_format == const.OUTPUT_FORMAT__CSV:
         df_path = sdb2df(sdb, job_id)
@@ -249,7 +318,7 @@ async def upload_dataset_to_db(
     errors = []
 
     for message, status_code in responses:
-        if status_code != 200:
+        if status_code not in [200, 201]:
             errors.append(message)
-            logger.error(message)
+            logger.error(f"{status_code}: {message}")
     return errors, len(data_frame)
